pyparsing.pyparsing_common

Module pyparsing :: Class pyparsing_common |
[frames] | no frames]

# Class pyparsing_common

source code

Here are some common low-level expressions that may be useful in jump-starting parser development:

- numeric forms (integers, reals, scientific notation)
- parse actions for converting numeric strings to Python int and/or float types
- common programming identifiers

Instance Methods
convertToInteger(t) Parse action for converting parsed integers to Python int | source code
convertToFloat(t) Parse action for converting parsed numbers to Python float | source code

Class Variables
| integer = `integer` expression that parses an unsigned integer and returns an int
| signedInteger = `signed integer` expression that parses an integer with optional leading sign and returns an int
| real = `real number` expression that parses a floating point number and returns a float
| sciReal = `real number with scientfic notation` expression that parses a floating point number with optional scientfic notation and returns a float
| numeric = `{real number with scientfic notation | real number |`...`` any numeric expression, returns the corresponding Python type
| number = `number` any int or real number, returned as float
| identifier = `identifier` typical code identifier

Class Variable Details

  ### numeric any numeric expression, returns the corresponding Python type Value:
      {real number with scientfic notation | real number | signed integer}